C Subroutine MAP_STEEL_FINE.  Produced by :-
C
C  N.A. Chester,
C  Phase Transformations Group,
C  Department of Materials Science and Metallurgy,
C  University of Cambridge,
C  Cambridge UK
C
C This subroutine searches for the volume fraction of bainite for a given 
C  temperature.  An equation is in the form: time equals a function of volume
C  fraction of bainite. To calculate the volume fraction of bainite for a 
C  given time the subroutine MAP_STEEL_ROUGH is used to find the value to an
C  accuracy of 0.01 volume fraction; MAP_STEEL_FINE is then called to calculate
C  the volume fraction to an accuracy of 0.0001.
C
C The equation used (in function MAP_STEEL_NEWF) is a solution of equation (28)
C  in [1] which has been integrated correctly. The integration uses a standard
C  solution found in [2].
C
C References :-
C
C 1. G.I. Rees and H.K.D.H. Bhadeshia,  Materials Science and Technology,
C  8, (November 1992), 985-993.
C
C 2. K. Rectorys, "Survey of Applicable Mathematics", ILIFFE Books Ltd,
C  London, 543, equation no. 410.
C
C 3. H.K.D.H. Bhadeshia,  J. Phys. (Orsay), <u>43</u>, (C4), 443-448.</p>
C
C Input arguments :-
C
C TEMP is the temperature (in kelvin).
C DGM is the initial value of the maximum nucleation free energy change (in
C  joules per mole).
C MAXVOL is the maximum volume fraction of bainite, taken to be that at which
C  the carbon concentration of the austenite reaches the To' line.
C ND is the grain size of the parental austenite (in micrometres).
C CD is an array of 4 constants optimised for this equation with experimental
C  data from [3], the values being :-
C     CD(1) =  0.34458D+02
C     CD(2) =  0.14750D+03
C     CD(3) =  0.20980D+05
C     CD(4) =  0.30327D+02
C XBAR is the mole fraction of carbon in the alloy.
C TTIME is the isothermal holding time for which the volume fraction bainite
C  is being calculated (in seconds).
C VHIGH is the volume fraction found by MAP_STEEL_ROUGH to be the first to take
C longer than time TTIME.
C
C Output arguments :-
C
C VOL is the volume fraction of bainite calculated, rounded up to the nearest
C  0.0001 volume fractions.
C
C----------------------------------------------------------------------------
C
       SUBROUTINE MAP_STEEL_FINE(TEMP,DGM,MAXVOL,ND,CNT,XBAR,
     & TTIME,VHIGH,VOL)
       IMPLICIT NONE
C
C Declare input and output arguments.
C
       DOUBLE PRECISION CNT(4)
       DOUBLE PRECISION DGM, MAXVOL, ND, PSI, TEMP, TIME, TTIME,
     & VHIGH, VOL
C
C Declare external functions
C
       DOUBLE PRECISION MAP_STEEL_NEWF
C
C Declare local variables.
C
       DOUBLE PRECISION VA, VLOW, XBAR
       INTEGER I
C
C Start of code.
C
       VLOW = VHIGH-0.01D0
       DO 20 I = 1,100
        VA   = VLOW+(I*0.00010D0)
        PSI  = VA/MAXVOL
        TIME = MAP_STEEL_NEWF(TEMP,DGM,PSI,MAXVOL,ND,CNT,XBAR)
        IF (TIME .GT. TTIME) THEN
           GOTO 30
        END  IF
20     CONTINUE
30     VOL = VA
C
       RETURN
       END
C
C----------------------------------------------------------------------------
